@@ -133,6 +133,10 @@ fetchSCAN <- function(site.code, year, report='SCAN', req=NULL) {
     return(.get_SCAN_data(req))
   }
   
+  # check for required packages
+  if(!requireNamespace('httr', quietly = TRUE))
+    stop('please install the `httr` package', call.=FALSE)
+  
   # init list to store results
   res <- list()
   
@@ -242,8 +246,15 @@ fetchSCAN <- function(site.code, year, report='SCAN', req=NULL) {
   idx <- which(!is.na(d.long$value))
   d.long <- d.long[idx, ]
   
+  # water year/day: October 1st -- September 30th
+  w <- waterDayYear(d.long$Date)
+  
+  # row-order is preserved
+  d.long$water_year <- w$wy
+  d.long$water_day <- w$wd
+  
   # format and return
-  return(d.long[, c('Site', 'Date', 'value', 'depth', 'sensor.id')])
+  return(d.long[, c('Site', 'Date', 'water_year', 'water_day', 'value', 'depth', 'sensor.id')])
 }
 
 # format a list request for SCAN data
@@ -264,10 +275,6 @@ fetchSCAN <- function(site.code, year, report='SCAN', req=NULL) {
   if(class(list) != 'list')
     req <- as.list(req)
   
-  # check for required packages
-  if(!requireNamespace('httr', quietly = TRUE))
-    stop('please install the `httr` package', call.=FALSE)
-  
   # base URL to service
   uri <- 'https://wcc.sc.egov.usda.gov/nwcc/view'
   
