@@ -1,21 +1,12 @@
 context("siblings() -- requires internet connection")
 
-## sample data
-x <- siblings('amador', component.data = TRUE)
-
-test_that("siblings() returns skeleton with bogus query", {
-  
-  # a skeleton list should be returned
-  res <- siblings('XXX')
-  expect_equal(class(res), 'list')
-  
-  # TODO: elements should be NULL vs. FALSE
-  
-})
-
 
 test_that("siblings() returns reasonable data", {
   
+  skip_if_offline()
+  
+  x <- siblings('amador', component.data = TRUE)
+  
   # standard request
   expect_equal(class(x), 'list')
   expect_equal(length(x), 2)
@@ -26,4 +17,18 @@ test_that("siblings() returns reasonable data", {
   expect_equal(names(x$sib), c('series', 'sibling', 'majcompflag', 'n'))
 })
 
+
+
+test_that("siblings() returns skeleton with bogus query", {
+  
+  skip_if_offline()
+  
+  # a skeleton list should be returned
+  res <- siblings('XXX')
+  expect_equal(class(res), 'list')
+  
+  # TODO: elements should be NULL vs. FALSE
+  
+})
+
 # TODO: test cousins
